<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

if ( ! function_exists( 'next_travel_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Next Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function next_travel_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'next_travel_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'next_travel_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Next Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function next_travel_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'next_travel_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'next_travel_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Next Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function next_travel_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'next_travel_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'next_travel_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Next Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function next_travel_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Check if Business Design Enable
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_third_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'next_travel_pro_theme_options[home_layout]' )->value();
	return ('third-design' == $home_layout )  ;
}


/**
 * Front Page Active Callbacks
 */

/*=================Slider Section===================*/

/**
 * Check if slider section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Slider section content type is trip.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if Slider section content type is trip types.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if Slider section content type is destination.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Slider section content type is activity.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[slider_content_type]' )->value();
	return next_travel_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

/*=================About Us section=======================*/

/**
 * Check if about section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options_about_content_type' )->value();
	return next_travel_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options_about_content_type' )->value();
	return next_travel_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is trip.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_about_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options_about_content_type' )->value();
	return next_travel_pro_is_about_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options_about_content_type' )->value();
	return next_travel_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*=================Gallery Slider Section===================*/

/**
 * Check if gallery_slider section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_section_enable]' )->value() );
}

/**
 * Check if gallery_slider section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery_slider section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery_slider section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Gallery Slider section content type is trip.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if Gallery Slider section content type is trip types.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if Gallery Slider section content type is destination.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Gallery Slider section content type is activity.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_gallery_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]' )->value();
	return next_travel_pro_is_gallery_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

/*====================Popular Destination========================*/
/**
 * Check if popular destination section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular Destination section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular Destination section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular Destination section content type is trip.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return next_travel_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/*=========================Counter Section==============================*/

/**
 * Check if counter section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[counter_section_enable]' )->value() );
}

/*====================recommended Destination========================*/
/**
 * Check if recommended destination section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_section_enable]' )->value() );
}

/**
 * Check if recommended destination section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Recommended Destination section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if Recommended Destination section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Recommended Destination section content type is trip.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if recommended destination section content type is trip types.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if recommended destination section content type is destination.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if recommended destination section content type is activity.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recommended_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]' )->value();
	return next_travel_pro_is_recommended_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/*=======================Blog=======================*/
/**
 * Check if blog section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[blog_section_enable]' )->value());
}

/**
 * Check if blog section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_title_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'next_travel_pro_theme_options[home_layout]' )->value();
	return ( next_travel_pro_is_blog_section_enable($control) && ($home_layout != 'fourth-design'));
}

/**
 * Check if blog section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[blog_content_type]' )->value();
	return next_travel_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[blog_content_type]' )->value();
	return next_travel_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[blog_content_type]' )->value();
	return next_travel_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[blog_content_type]' )->value();
	return next_travel_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type ) ;
}


/*======================Testimonial===============================*/
/**
 * Check if testimonial section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[testimonial_content_type]' )->value();
	return next_travel_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[testimonial_content_type]' )->value();
	return next_travel_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[testimonial_content_type]' )->value();
	return next_travel_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/*======================Service=====================*/

/**
 * Check if service section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[service_content_type]' )->value();
	return next_travel_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[service_content_type]' )->value();
	return next_travel_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[service_content_type]' )->value();
	return next_travel_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[service_content_type]' )->value();
	return next_travel_pro_is_service_section_enable( $control );
}

/*=======================Team==========================*/

/**
 * Check if team section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[team_content_type]' )->value();
	return next_travel_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[team_content_type]' )->value();
	return next_travel_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[team_content_type]' )->value();
	return next_travel_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*======================Recent News===============================*/
/**
 * Check if recent_news section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recent_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[recent_news_section_enable]' )->value() );
}

/**
 * Check if recent_news section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recent_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recent_news_content_type]' )->value();
	return next_travel_pro_is_recent_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_news section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recent_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recent_news_content_type]' )->value();
	return next_travel_pro_is_recent_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_news section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recent_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recent_news_content_type]' )->value();
	return next_travel_pro_is_recent_news_section_enable( $control ) && ( 'category' == $content_type );
}

/*========================Featured Posts=========================*/

/**
 * Check if featured_posts section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[featured_posts_content_type]' )->value();
	return next_travel_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[featured_posts_content_type]' )->value();
	return next_travel_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[featured_posts_content_type]' )->value();
	return next_travel_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*========================Latest Products========================*/

/**
 * Check if latest release section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[latest_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if latest release section content type is product.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_latest_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[latest_products_content_type]' )->value();
	return next_travel_pro_is_latest_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_latest_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[latest_products_content_type]' )->value();
	return next_travel_pro_is_latest_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*========================Popular Products=======================*/

/**
 * Check if popular_products section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[popular_products_section_enable]' )->value() );
}

function next_travel_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_products_content_type]' )->value();
	return next_travel_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

function next_travel_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[popular_products_content_type]' )->value();
	return next_travel_pro_is_popular_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*========================products collection====================*/
/**
 * Check if product section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[collection_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}
/*========================Recent Product=========================*/

/**
 * Check if recent_products section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[recent_products_section_enable]' )->value() );
}

function next_travel_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recent_products_content_type]' )->value();
	return next_travel_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

function next_travel_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[recent_products_content_type]' )->value();
	return next_travel_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*========================Featured Products======================*/


//featured section
function next_travel_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*========================Treanding Products=====================*/


function next_travel_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[trending_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function next_travel_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_1]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function next_travel_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_2]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function next_travel_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_3]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function next_travel_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_1]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function next_travel_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_2]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function next_travel_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'next_travel_pro_theme_options[trending_content_type_3]' )->value();
	return next_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

/*========================Subscription===========================*/
/**
 * Check if subscription section is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'next_travel_pro_theme_options[subscription_section_enable]' )->value() );
}



/**
 * Check if trip search title is enabled.
 *
 * @since Next Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function next_travel_pro_is_trip_search_title_enable( $control ) {
	return ( next_travel_pro_is_trip_search_enable($control) && $control->manager->get_setting( 'next_travel_pro_theme_options[trip_search_enable]' )->value() );
}
