<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'next_travel_pro_about_section', array(
	'title'             => esc_html__( 'About Us','next-travel-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// About Section enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_about_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[about_section_enable]',
    ) );
}

// About sub title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us h3.section-subtitle',
		'settings'            => 'next_travel_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_about_sub_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_excerpt_length]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_long_excerpt',
	'default'			=> $options['about_excerpt_length'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'next-travel-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'next-travel-pro' ),
	'section'     		=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// About content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options_about_content_type', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options_about_content_type', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_about_section_enable',
	'choices'			=> next_travel_pro_about_content_type(),
) );

// About pages drop down chooser control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_page',
) );

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_about_section',
	'choices'			=> next_travel_pro_page_choices(),
	'active_callback'	=> 'next_travel_pro_is_about_section_content_page_enable',
) ) );

// About posts drop down chooser control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_page',
) );

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_about_section',
	'choices'			=> next_travel_pro_post_choices(),
	'active_callback'	=> 'next_travel_pro_is_about_section_content_post_enable',
) ) );

// ABOUT trips drop down chooser control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_content_trip]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_page',
) );

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[about_content_trip]', array(
	'label'             => esc_html__( 'Select Trip', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_about_section',
	'choices'			=> next_travel_pro_trip_choices(),
	'active_callback'	=> 'next_travel_pro_is_about_section_content_trip_enable',
) ) );

// About title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );


// about description setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// about btn title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'next_travel_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us div.read-more a',
		'settings'            => 'next_travel_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_about_btn_title_partial',
		) );
	}

	// about btn link setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'next_travel_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_about_section',
	'active_callback' 	=> 'next_travel_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
	) );

//about image setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'next_travel_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'About Image', 'next-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'next-travel-pro' ), 500, 690 ),
		'section'     		=> 'next_travel_pro_about_section',
		'active_callback'	=> 'next_travel_pro_is_about_section_content_custom_enable',
) ) );

// about hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[about_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[about_hr]',
		array(
			'section'         => 'next_travel_pro_about_section',
			'active_callback' => 'next_travel_pro_is_about_section_enable',
			'type'			  => 'hr'
	) ) );

	require get_template_directory() . '/inc/customizer/sections/color/about.php';



