<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'next_travel_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','next-travel-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_blog_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[blog_section_enable]', array(
		'selector'            => '#latest-posts div.post-wrapper .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[blog_section_enable]',
    ) );
}

// blog sub title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[blog_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_blog_section',
	'type'				=> 'text',
	'active_callback' 	=> 'next_travel_pro_is_blog_title_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[blog_sub_title]', array(
		'selector'            => '#latest-posts h3.section-subtitle',
		'settings'            => 'next_travel_pro_theme_options[blog_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_blog_sub_title_partial',
    ) );
}

// blog title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_blog_section',
	'active_callback' 	=> 'next_travel_pro_is_blog_title_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[blog_title]', array(
		'selector'            => '#latest-posts h2.section-title',
		'settings'            => 'next_travel_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_blog_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_excerpt_length]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_long_excerpt',
	'default'			=> $options['blog_excerpt_length'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[blog_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'next-travel-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in blog posts.', 'next-travel-pro' ),
	'section'     		=> 'next_travel_pro_blog_section',	
	'active_callback' 	=> 'next_travel_pro_is_blog_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Blog content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_blog_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'      => esc_html__( 'Post', 'next-travel-pro' ),
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
            'recent' 	=> esc_html__( 'Recent', 'next-travel-pro' ),
        ),
) );

for ( $i = 1; $i <= 4; $i++ ) :
	// Blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_blog_section',
		'choices'			=> next_travel_pro_page_choices(),
		'active_callback'	=> 'next_travel_pro_is_blog_section_content_page_enable',
	) ) );

	// Blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_blog_section',
		'choices'			=> next_travel_pro_post_choices(),
		'active_callback'	=> 'next_travel_pro_is_blog_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Category_Control( $wp_customize,'next_travel_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'next_travel_pro_is_blog_section_content_recent_enable'
) ) );

// blog hr setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[blog_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[blog_hr]',
	array(
		'section'         => 'next_travel_pro_blog_section',
		'active_callback' => 'next_travel_pro_is_blog_section_enable',
		'type'			  => 'hr'
) ) );

require get_template_directory() . '/inc/customizer/sections/color/blog.php';
