<?php
/**
 * featured_products Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add featured_products section
$wp_customize->add_section( 'next_travel_pro_featured_products_section', array(
	'title'             => esc_html__( 'Featured Products','next-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// featured_products content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_section_enable]', array(
	'default'			=> 	$options['featured_products_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[featured_products_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_featured_products_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[featured_products_section_enable]', array(
        'selector'            => '#featured-products .tooltiptext',
        'settings'            => 'next_travel_pro_theme_options[featured_products_section_enable]',
    ) );
}

for ( $i = 1; $i <= 2; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'next_travel_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Featured Category ', 'next-travel-pro' ).$i,
		'section'           => 'next_travel_pro_featured_products_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'next_travel_pro_is_featured_products_section_enable'
	) ) );

	$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[featured_products_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Title ', 'next-travel-pro' ).$i,
		'section'        	=> 'next_travel_pro_featured_products_section',
		'active_callback' 	=> 'next_travel_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_short_description_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[featured_products_short_description_'.$i.']', array(
		'label'           	=> esc_html__( 'Short Description ', 'next-travel-pro' ).$i,
		'section'        	=> 'next_travel_pro_featured_products_section',
		'active_callback' 	=> 'next_travel_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

endfor;

// featured_products btn title setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_btn_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[featured_products_btn_title]', array(
		'label'           	=> esc_html__( 'Button Label ', 'next-travel-pro' ),
		'section'        	=> 'next_travel_pro_featured_products_section',
		'active_callback' 	=> 'next_travel_pro_is_featured_products_section_enable',
		'type'				=> 'text',
		) );

	// featured_products_ hr setting and control
    $wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_hr]', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[featured_products_hr]',
        array(
            'section'         => 'next_travel_pro_featured_products_section',
            'active_callback' => 'next_travel_pro_is_featured_products_section_enable',
            'type'            => 'hr'
    ) ) );
    
//color options

// Section background color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_bg_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[featured_products_bg_color]', array(
    'label'             => esc_html__( 'Background Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_featured_products_section',
    'active_callback'   => 'next_travel_pro_is_featured_products_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_btn_bg_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[featured_products_btn_bg_color]', array(
    'label'             => esc_html__( 'Button BG Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_featured_products_section',
    'active_callback'   => 'next_travel_pro_is_featured_products_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_btn_bg_hover_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[featured_products_btn_bg_hover_color]', array(
    'label'             => esc_html__( 'Button BG Hover Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_featured_products_section',
    'active_callback'   => 'next_travel_pro_is_featured_products_section_enable',
    ) ) );

// Section bitton text setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[featured_products_btn_text_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[featured_products_btn_text_color]', array(
    'label'             => esc_html__( 'Button Text Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_featured_products_section',
    'active_callback'   => 'next_travel_pro_is_featured_products_section_enable',
    ) ) );

