<?php
/**
 * Latest Products Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
	if( !class_exists( 'WooCommerce' ) ){
		return;
	}

// Add Latest Products section
$wp_customize->add_section( 'next_travel_pro_latest_products_section', array(
	'title'             => esc_html__( 'Latest Products','next-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Latest Products content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[latest_products_section_enable]', array(
	'default'			=> 	$options['latest_products_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[latest_products_section_enable]', array(
	'label'             => esc_html__( 'Latest Products Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_latest_products_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[latest_products_section_enable]', array(
		'selector'            => '#latest-products .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[latest_products_section_enable]',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[latest_products_count]', array(
	'default'          	=> $options['latest_products_count'],
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_latest_products_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[latest_products_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'next-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_latest_products_section',
	'active_callback'   => 'next_travel_pro_is_latest_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Latest Products content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[latest_products_content_type]', array(
	'default'          	=> $options['latest_products_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[latest_products_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_latest_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_latest_products_section_enable',
	'choices'			=> array(
		'product'   		 => esc_html__( 'Product', 'next-travel-pro' ),
		'product-category'   => esc_html__( 'Product Category', 'next-travel-pro' ),
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[latest_products_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[latest_products_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_latest_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_latest_products_section_content_product_category_enable'
) ) );

for ( $i = 1; $i <= $options['latest_products_count']; $i++ ) :

	// latest_products posts drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[latest_products_content_product_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[latest_products_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_latest_products_section',
		'choices'			=> next_travel_pro_product_choices(),
		'active_callback'	=> 'next_travel_pro_is_latest_products_section_content_product_enable',
	) ) );

endfor;

// latest_products hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[latest_products_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[latest_products_hr]',
		array(
			'section'         => 'next_travel_pro_latest_products_section',
			'active_callback' => 'next_travel_pro_is_latest_products_section_enable',
			'type'			  => 'hr'
	) ) );

	require get_template_directory() . '/inc/customizer/sections/color/latest-products.php';