<?php
/**
 * Products Collection Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add collection section
$wp_customize->add_section( 'next_travel_pro_collection_section', array(
	'title'             => esc_html__( 'Products Collection','next-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// collection content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_section_enable]', array(
	'default'			=> 	$options['collection_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[collection_section_enable]', array(
	'label'             => esc_html__( 'collection Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_collection_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[collection_section_enable]', array(
        'selector'            => '#products-collection div.section-header .tooltiptext',
        'settings'            => 'next_travel_pro_theme_options[collection_section_enable]',
    ) );
}

// collection title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['collection_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_collection_section',
	'active_callback' 	=> 'next_travel_pro_is_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[collection_title]', array(
        'selector'            => '#products-collection h2.section-title',
        'settings'            => 'next_travel_pro_theme_options[collection_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'next_travel_pro_collection_title_partial',
    ) );
}

// collection subtitle setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['collection_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[collection_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_collection_section',
	'active_callback' 	=> 'next_travel_pro_is_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[collection_subtitle]', array(
        'selector'            => '#products-collection h3.section-subtitle',
        'settings'            => 'next_travel_pro_theme_options[collection_subtitle]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'next_travel_pro_collection_subtitle_partial',
    ) );
}

for ( $i = 1; $i <= 4; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'next_travel_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[collection_content_collection_category_'.$i.']', array(
		'label'             => esc_html__( 'Select collection Category ', 'next-travel-pro' ).$i,
		'section'           => 'next_travel_pro_collection_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'next_travel_pro_is_collection_section_enable'
	) ) );

	$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_banner_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[collection_banner_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Banner Title ', 'next-travel-pro' ).$i,
		'section'        	=> 'next_travel_pro_collection_section',
		'active_callback' 	=> 'next_travel_pro_is_collection_section_enable',
		'type'				=> 'text',
	) );

endfor;

// collection hr setting and control
    $wp_customize->add_setting( 'next_travel_pro_theme_options[collection_hr]', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[collection_hr]',
        array(
            'section'         => 'next_travel_pro_collection_section',
            'active_callback' => 'next_travel_pro_is_collection_section_enable',
            'type'            => 'hr'
    ) ) );
    
//color options

// Section background color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_bg_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[collection_bg_color]', array(
    'label'             => esc_html__( 'Background Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_collection_section',
    'active_callback'   => 'next_travel_pro_is_collection_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_sub_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[collection_sub_title_color]', array(
    'label'             => esc_html__( 'Section Sub Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_collection_section',
    'active_callback'   => 'next_travel_pro_is_collection_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[collection_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[collection_title_color]', array(
    'label'             => esc_html__( 'Section Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_collection_section',
    'active_callback'   => 'next_travel_pro_is_collection_section_enable',
    ) ) );