<?php
/**
 * Recommended Destination Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Recommended Destination section
$wp_customize->add_section( 'next_travel_pro_recommended_destination_section', array(
	'title'             => esc_html__( 'Recommended Destination','next-travel-pro' ),
	'description'       => esc_html__( 'Recommended Destination Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Recommended Destination content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_section_enable]', array(
	'default'			=> 	$options['recommended_destination_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[recommended_destination_section_enable]', array(
	'label'             => esc_html__( 'Recommended Destination Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_section_enable]', array(
		'selector'            => '#recommended-destinations .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_sub_title]', array(
	'default'			=> $options['recommended_destination_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_sub_title]', array(
		'selector'            => '#recommended-destinations h3.section-subtitle',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recommended_destination_sub_title_partial',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_title]', array(
	'default'			=> $options['recommended_destination_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_title]', array(
		'selector'            => '#recommended-destinations h2.section-title',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recommended_destination_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_description]', array(
	'default'			=> $options['recommended_destination_description'],
	'sanitize_callback' => 'next_travel_pro_santize_allow_tag',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_description]', array(
	'label'           	=> esc_html__( 'Description', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_description]', array(
		'selector'            => '#recommended-destinations div.entry-content',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recommended_destination_description_partial',
    ) );
}

if( $options['home_layout'] == 'default-design'  || $options['home_layout'] == 'default-design-all'):

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_post_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recommended_destination_post_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_post_btn_label]', array(
	'label'           	=> esc_html__( 'Post Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_post_btn_label]', array(
		'selector'            => '#recommended-destinations div.recommended-destination-item a.add-to-list',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_post_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recommended_destination_post_btn_label_partial',
    ) );
}

endif;

// Recommended Destination content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_content_type]', array(
	'default'          	=> $options['recommended_destination_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'choices'			=> next_travel_pro_recommended_destination_content_type(),
) );

for ( $i = 1; $i <= 4; $i++ ) :

	// Recommended Destination pages drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[recommended_destination_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_recommended_destination_section',
		'choices'			=> next_travel_pro_page_choices(),
		'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_page_enable',
	) ) );

	// Recommended Destination posts drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[recommended_destination_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_recommended_destination_section',
		'choices'			=> next_travel_pro_post_choices(),
		'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_post_enable',
	) ) );
	
	// Recommended Destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[recommended_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_recommended_destination_section',
		'choices'			=> next_travel_pro_trip_choices(),
		'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_trip_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[recommended_destination_content_category]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[recommended_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_category_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[recommended_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[recommended_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[recommended_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[recommended_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[recommended_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[recommended_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recommended_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_recommended_destination_section_content_destination_enable'
) ) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recommended_destination_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_btn_label]', array(
	'label'           	=> esc_html__( 'Section Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recommended_destination_btn_label]', array(
		'selector'            => '#recommended-destinations div.read-more a',
		'settings'            => 'next_travel_pro_theme_options[recommended_destination_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recommended_destination_btn_label_partial',
    ) );
}

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recommended_destination_btn_url]', array(
	'label'           	=> esc_html__( 'Section Button URL', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recommended_destination_section',
	'active_callback' 	=> 'next_travel_pro_is_recommended_destination_section_enable',
	'type'				=> 'url',
) );

// recommended_destination hr setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recommended_destination_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[recommended_destination_hr]',
	array(
		'section'         => 'next_travel_pro_recommended_destination_section',
		'active_callback' => 'next_travel_pro_is_recommended_destination_section_enable',
		'type'			  => 'hr'
		) ) );

require get_template_directory() . '/inc/customizer/sections/color/recommended-destination.php';
