<?php
/**
 * trending_product Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}
// Add trending_product section
$wp_customize->add_section( 'next_travel_pro_trending_product_section', array(
	'title'             => esc_html__( 'Trending Product','next-travel-pro' ),
	'description'       => esc_html__( 'Trending Product Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// trending_product content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_section_enable]', array(
	'default'			=> 	$options['trending_product_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[trending_product_section_enable]', array(
	'label'             => esc_html__( 'Trending Product Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_trending_product_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[trending_product_section_enable]', array(
        'selector'            => '#trending-products .tooltiptext',
        'settings'            => 'next_travel_pro_theme_options[trending_product_section_enable]',
    ) );
}

$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_count]', array(
	'default'          	=> $options['trending_product_count'],
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_trending_product_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[trending_product_count]', array(
	'label'             => esc_html__( 'Number of Product Per Column', 'next-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_trending_product_section',
	'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for( $i = 1 ; $i <= 3 ; $i++ ){

$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_column_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Next_Travel_Pro_Customize_Column( $wp_customize, 'next_travel_pro_theme_options[trending_product_column_'. $i .']',
	array(
		'label'			  => esc_html__('Column ', 'next-travel-pro').$i,
		'section'         => 'next_travel_pro_trending_product_section',
		'active_callback' => 'next_travel_pro_is_trending_product_section_enable',
		'type'			  => 'column'
) ) );

// trending_product title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_title_'.$i.']', array(
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[trending_product_title_'.$i.']', array(
    'label'             => esc_html__( 'Title', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_trending_product_section',
    'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
    'type'              => 'text',
) );

$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_content_type_'.$i.']', array(
	'default'          	=> 'product',
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[trending_content_type_'.$i.']', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_trending_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_trending_product_section_enable',
	'choices'			=> array(
		'product'           => esc_html__( 'Product', 'next-travel-pro' ),
		'product_cat'       => esc_html__( 'Product Category', 'next-travel-pro' ),
		),
) );

for ( $j=1 ; $j <= $options['trending_product_count'] ; $j++ ) { 
	$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_content_page_'. $i.$j. ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[trending_product_content_page_' .$i.$j. ']', array(
			'label'             => sprintf( esc_html__( 'Select Product %d', 'next-travel-pro' ), $j ),
			'section'           => 'next_travel_pro_trending_product_section',
			'choices'			=> next_travel_pro_product_choices(),
			'active_callback'	=> 'next_travel_pro_is_trending_product_section_content_product_enable_'.$i,

	) ) );
}

$wp_customize->add_setting(  'next_travel_pro_theme_options[trending_product_category_'.$i.']', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_integers',
	) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[trending_product_category_'.$i.']', array(
	'label'             => esc_html__( 'Select Product Categories', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_trending_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_trending_product_section_content_category_enable_'.$i,

) ) );

$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_product_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[trending_product_hr_'. $i .']',
	array(
		'section'         => 'next_travel_pro_trending_product_section',
		'active_callback' => 'next_travel_pro_is_trending_product_section_enable',
		'type'			  => 'hr'
) ) );

}

// trending_products hr setting and control
    $wp_customize->add_setting( 'next_travel_pro_theme_options[trending_products_hr]', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[trending_products_hr]',
        array(
            'section'         => 'next_travel_pro_trending_product_section',
            'active_callback' => 'next_travel_pro_is_trending_product_section_enable',
            'type'            => 'hr'
    ) ) );
    
//color options

// Section background color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_products_bg_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[trending_products_bg_color]', array(
    'label'             => esc_html__( 'Background Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_trending_product_section',
    'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_products_section_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[trending_products_section_title_color]', array(
    'label'             => esc_html__( 'Section Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_trending_product_section',
    'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
    ) ) );

// sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_products_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[trending_products_title_color]', array(
    'label'             => esc_html__( 'Product Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_trending_product_section',
    'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
    ) ) );

// sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[trending_products_title_hover_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[trending_products_title_hover_color]', array(
    'label'             => esc_html__( 'Product Title Hover Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_trending_product_section',
    'active_callback'   => 'next_travel_pro_is_trending_product_section_enable',
    ) ) );