<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Next Travel Pro 1.0.0
    */
    function next_travel_pro_add_counter_section() {
        $options = next_travel_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'next_travel_pro_section_status', true, 'counter_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design-all', 'default-design', 'second-design', 'fourth-design', 'sixth-design' ) ) ) {
            $counter_enable = false;
        }

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        next_travel_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'next_travel_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_counter_section() {
        $options = next_travel_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $subtitle   = empty( $options['counter_sub_title'] ) ? '' : $options['counter_sub_title'] ;
        $title   = empty( $options['counter_title'] ) ? '' : $options['counter_title'] ;
        $column = ! empty( $options['counter_column'] ) ? $options['counter_column'] : 'col-4';
        $contents = array();

         for( $i= 1; $i <=$options['counter_count'] ; $i++ ){
            
            $page_post['title']     = empty( $options['counter_title_'.$i] ) ? '' :$options['counter_title_'.$i];
            $page_post['number']    = empty( $options['counter_number_'.$i] ) ? '' :$options['counter_number_'.$i];
            array_push( $contents, $page_post );
        }
       
        ?>
        <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'counter-section' );
                endif; ?>
                <?php if( in_array($options['home_layout'], array( 'default-design-all', 'default-design', 'fourth-design', 'sixth-design' )) ): ?>
                    <div class="section-header">
                        <h3 class="section-subtitle"><?php echo esc_html( $subtitle ); ?></h3>
                        <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                        <span class="separator"></span>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="<?php echo esc_attr( $column ); ?> clear">

                    <?php foreach ( $contents as $content ): ?>
                        
                        <article>
                            <div class="counter-item">
                                <h2 class="counter-value"><?php echo esc_html( $content['number'] ); ?></h2>
                                <h3 class="counter-title"><?php echo esc_html( $content['title'] ); ?> </h3>
                            </div><!-- .counter-item -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .col-4 -->
            </div><!-- .wrapper -->
        </div><!-- #counter-section -->

    <?php }
endif;
