<?php
/**
 * Featured Posts section
 *
 * This is the template for the content of recent_news section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_featured_posts_section' ) ) :
    /**
    * Add recent_news section
    *
    *@since Next Travel Pro 1.0.0
    */
    function next_travel_pro_add_featured_posts_section() {
        $options = next_travel_pro_get_theme_options();
        // Check if recent_news is enabled on frontpage
        $featured_posts_enable = apply_filters( 'next_travel_pro_section_status', true, 'featured_posts_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design-all', 'fifth-design' ) ) ) {
            $featured_posts_enable = false;
        }

        if ( true !== $featured_posts_enable ) {
            return false;
        }
        // Get recent_news section details
        $section_details = array();
        $section_details = apply_filters( 'next_travel_pro_filter_featured_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent_news section now.
        next_travel_pro_render_featured_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'next_travel_pro_get_featured_posts_section_details' ) ) :
    /**
    * recent_news section details.
    *
    * @since Next Travel Pro 1.0.0
    * @param array $input recent_news section details.
    */
    function next_travel_pro_get_featured_posts_section_details( $input ) {
        $options = next_travel_pro_get_theme_options();

        // Content type.
        $featured_posts_content_type   = $options['featured_posts_content_type'];
        $featured_posts_count          = ! empty( $options['featured_posts_count'] ) ? $options['featured_posts_count'] : 3;
        $content = array();
        switch ( $featured_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['featured_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['featured_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_posts_content_category'] ) ? $options['featured_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
            
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_news section content details.
add_filter( 'next_travel_pro_filter_featured_posts_section_details', 'next_travel_pro_get_featured_posts_section_details' );


if ( ! function_exists( 'next_travel_pro_render_featured_posts_section' ) ) :
  /**
   * Start recent_news section
   *
   * @return string recent_news content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_featured_posts_section( $content_details = array() ) {
        $options = next_travel_pro_get_theme_options();
        $featured_posts_content_type   = $options['featured_posts_content_type'];
        $image   = empty( $options['featured_posts_image'] ) ? '' : $options['featured_posts_image'] ;
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-posts" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
            <div class="wrapper">

            <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'featured-posts' );
                endif; ?>
                <div class="col-3 clear">

                    <?php foreach ($content_details as $content ): ?>

                        <article class="has-post-thumbnail">
                            <div class="featured-post-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <?php if( $featured_posts_content_type !== 'page' ): ?>
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                             <?php the_category( '', '', $content['id'] ); ?>
                                         </span><!-- .cat-links -->
                                     </div><!-- .entry-meta -->
                                 <?php endif; ?>

                                 <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                            </div><!-- .entry-container -->
                        </div><!-- .featured-post-item -->
                    </article>

                <?php endforeach; ?>

            </div><!-- .col-3 -->
        </div><!-- .wrapper -->
    </div><!-- #featured-posts -->

    <?php }
endif;
