<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Top Travel Pro 1.0.0
    */
    function next_travel_pro_add_service_section() {
        $options = next_travel_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'next_travel_pro_section_status', true, 'service_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design-all', 'second-design', 'fourth-design', 'sixth-design' ) ) ) {
             $service_enable = false;
        }

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'next_travel_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        next_travel_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'next_travel_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input service section details.
    */
    function next_travel_pro_get_service_section_details( $input ) {
        $options = next_travel_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count  = ! empty( $options['service_count'] ) ? $options['service_count'] : 3;
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $service_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = next_travel_pro_trim_content( $options['service_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'next_travel_pro_filter_service_section_details', 'next_travel_pro_get_service_section_details' );


if ( ! function_exists( 'next_travel_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Top Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_service_section( $content_details = array() ) {
        $options = next_travel_pro_get_theme_options();
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 

        <div id="our-services" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'our-services' );
                endif; ?>
            <?php if( in_array($options['home_layout'], array('default-design-all', 'second-design', 'sixth-design')) ){ ?>
                <div class="section-header">
                <?php if( !empty( $options['service_sub_title'] ) ): ?>
                    <h3 class="section-subtitle"><?php echo esc_html( $options['service_sub_title'] ) ; ?></h3>
                <?php endif; 
                if( !empty( $options['service_title'] ) ):
                ?>
                    <h2 class="section-title"><?php echo esc_html( $options['service_title'] ) ; ?></h2>
                <?php endif; ?>
                    <span class="separator"></span>
                </div><!-- .section-header -->

                <?php } ?>

                <div class="section-content col-3 clear">

                <?php foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="service-item-wrapper">
                            <div class="icon-container">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-meetup'; ?>"></i></a>
                            </div><!-- .icon-container -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div><!-- service-item-wrapper -->
                    </article>

                    <?php $i++; endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #our-services -->
        
    <?php }
endif;