<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Next Travel Pro 1.0.0
    */
    function next_travel_pro_add_testimonial_section() {
        $options = next_travel_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'next_travel_pro_section_status', true, 'testimonial_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design-all', 'default-design', 'second-design', 'fourth-design', 'sixth-design') ) ) {
            $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'next_travel_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        next_travel_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'next_travel_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Next Travel Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function next_travel_pro_get_testimonial_section_details( $input ) {
        $options = next_travel_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
            
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = next_travel_pro_trim_content( $options['testimonial_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'next_travel_pro_filter_testimonial_section_details', 'next_travel_pro_get_testimonial_section_details' );


if ( ! function_exists( 'next_travel_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_testimonial_section( $content_details = array() ) {
        $options = next_travel_pro_get_theme_options();

        $testimonial_title     = ! empty( $options['testimonial_title'] ) ? $options['testimonial_title'] : '';
        $testimonial_sub_title = ! empty( $options['testimonial_sub_title'] ) ? $options['testimonial_sub_title'] : '';
        $testimonial_background_image = ! empty( $options['testimonial_background_image'] ) ? $options['testimonial_background_image'] : '';
        $testimonial_auto_play    = ($options['testimonial_auto_play'] == true ) ? 'true' : 'false';
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="testimonial-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $testimonial_background_image ); ?>');">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'testimonial-section' );
                endif; ?>
                <div class="section-header">
                    <?php if( !empty( $testimonial_sub_title ) ): ?>
                        <h3 class="section-subtitle"><?php echo esc_html( $testimonial_sub_title ); ?></h3>
                    <?php endif;
                    if( !empty( $testimonial_title ) ):
                       ?>
                   <h2 class="section-title"><?php echo esc_html( $testimonial_title ); ?></h2>
               <?php endif; ?>
           </div><!-- .section-header -->

           <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $testimonial_auto_play ); ?>, "draggable": true, "fade": false }'>

            <?php foreach($content_details as $i => $content): ?> 

                <article>
                    <div class="testimonial-item">
                        <?php if( !empty( $content['image'] ) ): ?>
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="testimonial-<?php echo esc_attr($i+1); ?>"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <span class="separator"></span>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>
                        </div><!-- .entry-container -->
                    </div><!-- .testimonial-item -->
                </article>

            <?php endforeach; ?>

        </div><!-- .section-content -->
    </div><!-- .wrapper -->
</div><!-- #testimonial-section -->

    <?php }
endif;
